@@ -134,7 +134,7 @@ main (int argc, char *argv[])
 	}
 
 	gtk_window_set_default_icon_name ("gnome-nettool");
-	
+
 	builder = gtk_builder_new ();
         gtk_builder_add_from_file (builder, dialog, NULL);
 	window = GTK_WIDGET (gtk_builder_get_object (builder, "main_window"));
@@ -315,7 +315,7 @@ load_ping_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (pinger->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (pinger->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (pinger->host), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (pinger->host)));
 	
@@ -327,7 +327,7 @@ load_ping_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	pinger->history = gn_combo_history_new ();
-	gn_combo_history_set_id (pinger->history, "GNOME_Network_netinfo_host");
+	gn_combo_history_set_id (pinger->history, "hostnames");
 	gn_combo_history_set_combo (pinger->history, GTK_COMBO_BOX (pinger->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -394,7 +394,7 @@ load_traceroute_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (tracer->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (tracer->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (tracer->host), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (tracer->host)));
 
@@ -406,7 +406,7 @@ load_traceroute_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	tracer->history = gn_combo_history_new ();
-	gn_combo_history_set_id (tracer->history, "GNOME_Network_netinfo_host");
+	gn_combo_history_set_id (tracer->history, "hostnames");
 	gn_combo_history_set_combo (tracer->history, GTK_COMBO_BOX (tracer->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -633,7 +633,7 @@ load_scan_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (scan->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (scan->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (scan->host), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (scan->host)));
 
@@ -645,7 +645,7 @@ load_scan_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	scan->history = gn_combo_history_new ();
-	gn_combo_history_set_id (scan->history, "GNOME_Network_netinfo_host");
+	gn_combo_history_set_id (scan->history, "hostnames");
 	gn_combo_history_set_combo (scan->history, GTK_COMBO_BOX (scan->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -757,7 +757,7 @@ load_lookup_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (lookup->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (lookup->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (lookup->host), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (lookup->host)));
 
@@ -769,7 +769,7 @@ load_lookup_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	lookup->history = gn_combo_history_new ();
-	gn_combo_history_set_id (lookup->history, "GNOME_Network_netinfo_host");
+	gn_combo_history_set_id (lookup->history, "hostnames");
 	gn_combo_history_set_combo (lookup->history, GTK_COMBO_BOX (lookup->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -840,7 +840,7 @@ load_finger_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (finger->user), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->user), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->user), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->user)));
 
@@ -852,7 +852,7 @@ load_finger_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	finger->history_user = gn_combo_history_new ();
-	gn_combo_history_set_id (finger->history_user, "GNOME_Network_netinfo_user");
+	gn_combo_history_set_id (finger->history_user, "usernames");
 	gn_combo_history_set_combo (finger->history_user, GTK_COMBO_BOX (finger->user));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -863,7 +863,7 @@ load_finger_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (finger->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (finger->host), 0);
 
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (finger->host)));
 
@@ -875,7 +875,7 @@ load_finger_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	finger->history = gn_combo_history_new ();
-	gn_combo_history_set_id (finger->history, "GNOME_Network_netinfo_host");
+	gn_combo_history_set_id (finger->history, "hostnames");
 	gn_combo_history_set_combo (finger->history, GTK_COMBO_BOX (finger->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
@@ -944,7 +944,7 @@ load_whois_widgets_from_builder (GtkBuilder * builder)
 	gtk_combo_box_set_model (GTK_COMBO_BOX (whois->host), model);
 	g_object_unref (model);
 
-	/*gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (whois->host), 0);*/
+	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (whois->host), 0);
 	
 	entry_host = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (whois->host)));
 	
@@ -956,7 +956,7 @@ load_whois_widgets_from_builder (GtkBuilder * builder)
 	g_object_unref (model);
 
 	whois->history = gn_combo_history_new ();
-	gn_combo_history_set_id (whois->history, "GNOME_Network_netinfo_domain");
+	gn_combo_history_set_id (whois->history, "domains");
 	gn_combo_history_set_combo (whois->history, GTK_COMBO_BOX (whois->host));
 
 	g_signal_connect (G_OBJECT (entry_host), "activate",
